==> haskell-brick-0.47.1-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: brick
version: 0.47.1
id: brick-0.47.1-1B9g9JkZVg8AAe7RbJ3pLX
key: brick-0.47.1-1B9g9JkZVg8AAe7RbJ3pLX
license: BSD-3-Clause
copyright: (c) Jonathan Daugherty 2015-2018
maintainer: Jonathan Daugherty <cygnus@foobox.com>
author: Jonathan Daugherty <cygnus@foobox.com>
homepage: https://github.com/jtdaugherty/brick/
synopsis: A declarative terminal user interface library
description:
    Write terminal applications painlessly with '\''brick'\''! You write an
    event handler and a drawing function and the library does the rest.
    .
    .
    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui
    .
    .
    To get started, see:
    .
    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>
    .
    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>
    .
    * The demonstration programs in the '\''programs'\'' directory
    .
    .
    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.
category: Graphics
abi: 4ef11391a27bc489fa678725afdf68bb
exposed: True
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.BorderMap Brick.Focus
    Brick.Forms Brick.Main Brick.Markup Brick.Themes Brick.Types
    Brick.Util Brick.Widgets.Border Brick.Widgets.Border.Style
    Brick.Widgets.Center Brick.Widgets.Core Brick.Widgets.Dialog
    Brick.Widgets.Edit Brick.Widgets.FileBrowser Brick.Widgets.List
    Brick.Widgets.ProgressBar Data.IMap Data.Text.Markup
hidden-modules: Brick.Types.Common Brick.Types.TH
                Brick.Types.Internal Brick.Widgets.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/brick-0.47.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/brick-0.47.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/brick-0.47.1
hs-libraries: HSbrick-0.47.1-1B9g9JkZVg8AAe7RbJ3pLX
depends:
    base-4.12.0.0 config-ini-0.2.4.0-Fro52tkG3Cl1rw3W8zqieo
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    data-clist-0.1.2.3-DnwBVJdh6RfDhYZPvG1Vij deepseq-1.4.4.0
    directory-1.3.3.0 dlist-0.8.0.7-4YlHXedX3EE3dGnI3L89Bl
    filepath-1.4.2.1 microlens-0.4.11.2-Ecy0HNwIglV6pyNsLPomsR
    microlens-mtl-0.2.0.1-YTFbHudevv9mEzCYQBIKT
    microlens-th-0.4.3.2-BtNcM50Dy9m529DwUGkRbV stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    text-zipper-0.10.1-JkqGgN6zbRU5SddSjNsQLm transformers-0.5.6.2
    unix-2.7.2.2 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vty-5.25.1-F5xVvWOSlWZ32zpkNH6vGH
    word-wrap-0.4.1-4ZVwjJZle6Z5iJWI2Iyznf
haddock-interfaces: /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html: /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-brick-0.48-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: brick
version: 0.48
id: brick-0.48-2vadshGu3p8wN281ViQts
key: brick-0.48-2vadshGu3p8wN281ViQts
license: BSD-3-Clause
copyright: (c) Jonathan Daugherty 2015-2018
maintainer: Jonathan Daugherty <cygnus@foobox.com>
author: Jonathan Daugherty <cygnus@foobox.com>
homepage: https://github.com/jtdaugherty/brick/
synopsis: A declarative terminal user interface library
description:
    Write terminal applications painlessly with '\''brick'\''! You write an
    event handler and a drawing function and the library does the rest.
    .
    .
    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui
    .
    .
    To get started, see:
    .
    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>
    .
    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>
    .
    * The demonstration programs in the '\''programs'\'' directory
    .
    .
    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.
category: Graphics
abi: fb1b3df1735b546801b59d44d11e6134
exposed: True
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.BorderMap Brick.Focus
    Brick.Forms Brick.Main Brick.Markup Brick.Themes Brick.Types
    Brick.Util Brick.Widgets.Border Brick.Widgets.Border.Style
    Brick.Widgets.Center Brick.Widgets.Core Brick.Widgets.Dialog
    Brick.Widgets.Edit Brick.Widgets.FileBrowser Brick.Widgets.List
    Brick.Widgets.ProgressBar Data.IMap Data.Text.Markup
hidden-modules: Brick.Types.Common Brick.Types.TH
                Brick.Types.Internal Brick.Widgets.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/brick-0.48
library-dirs: /usr/lib/ghc-8.6.5/site-local/brick-0.48
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/brick-0.48
hs-libraries: HSbrick-0.48-2vadshGu3p8wN281ViQts
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    config-ini-0.2.4.0-aHNYb6hkm1mVtph4t2d5 containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    data-clist-0.1.2.3-DnwBVJdh6RfDhYZPvG1Vij deepseq-1.4.4.0
    directory-1.3.3.0 dlist-0.8.0.7-4YlHXedX3EE3dGnI3L89Bl
    filepath-1.4.2.1 microlens-0.4.11.2-Ecy0HNwIglV6pyNsLPomsR
    microlens-mtl-0.2.0.1-YTFbHudevv9mEzCYQBIKT
    microlens-th-0.4.3.2-BtNcM50Dy9m529DwUGkRbV stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    text-zipper-0.10.1-JkqGgN6zbRU5SddSjNsQLm transformers-0.5.6.2
    unix-2.7.2.2 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vty-5.26-ClI9KCW12KTGwz4m9lEEAl
    word-wrap-0.4.1-4ZVwjJZle6Z5iJWI2Iyznf
haddock-interfaces: /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html: /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
